@@ -106,7 +106,7 @@ To configure signal polarities or quadrature directions, some enumerations are d
     trsi.quadrature_direction = Direction.REVERSE
 """
 
-__version__ = "1.4.1"
+__version__ = "1.4.3"
 
 import logging
 import asyncio
@@ -292,6 +292,13 @@ class TRSInterface():
             self.stop()
             # Schedule next check
             self._loop.call_later(self.read_interval, self._schedule_reads)
+        except ValueError:
+            # Unpacking of data failed (bytes gone missing somewhere?)
+            # We'll need to throw this set of data away, but hopefully not die completely
+            self._log.error("Error unpacking data received from device.")
+            self.stop()
+            # Schedule next check
+            self._loop.call_later(self.read_interval, self._schedule_reads)
 
     def _schedule_updates(self):
         """
